@@ -53,7 +53,7 @@ uint Genome::OpenStream(string name, ifstream & stream, uint size)
     if (!stream.good()) {
         ostringstream errOut;
         errOut << "EXITING because of FATAL ERROR: could not open genome file "<< P->genomeDir << "/" << name <<"\n" << endl;
-        errOut << "SOLUTION: check that the path to genome files, specified in --genomeDir is correct and the files are present, and have user read permsissions\n" <<flush;
+        errOut << "SOLUTION: check that the path to genome files, specified in --genomeDir is correct and the files are present, and have user read permissions\n" <<flush;
         exitWithError(errOut.str(),std::cerr, P->inOut->logMain, EXIT_CODE_GENOME_FILES, *P);
     };
 
@@ -513,7 +513,9 @@ void Genome::genomeLoad(){//allocate and load Genome
                 << (1LLU<<P->winBinNbits)*P->winAnchorDistNbins <<endl;
     } else {
         //redefine winBinNbits
-        P->winBinNbits=max( (uint) floor(log2(P->nGenome/40000)+0.5), (uint) floor(log2(max(max(4LLU,P->alignIntronMax),P->alignMatesGapMax)/4)+0.5) );
+        P->winBinNbits = (uint) floor( log2( max( max(4LLU,P->alignIntronMax), (P->alignMatesGapMax==0 ? 1000LLU : P->alignMatesGapMax) ) /4 ) + 0.5);
+        P->winBinNbits = max( P->winBinNbits, (uint) floor(log2(P->nGenome/40000+1)+0.5) ); 
+        //ISSUE - to be fixed in STAR3: if alignIntronMax>0 but alignMatesGapMax==0, winBinNbits will be defined by alignIntronMax
         P->inOut->logMain << "To accomodate alignIntronMax="<<P->alignIntronMax<<" redefined winBinNbits="<< P->winBinNbits <<endl;
     };
 
