@@ -30,7 +30,7 @@ class Genome {
     char *shmStart;
     char *G1; //pointer -200 of G
     SharedMemory * sharedMemory;
-    uint OpenStream(string name, ifstream & stream);
+    uint OpenStream(string name, ifstream & stream, uint size);
     void HandleSharedMemoryException(const SharedMemoryException & exc, uint64 shmSize);
 
 };
