@@ -45,10 +45,14 @@ Parameters::Parameters() {//initalize parameters info
     parArray.push_back(new ParameterInfoScalar <uint> (-1, -1, "genomeSAsparseD", &genomeSAsparseD));
     parArray.push_back(new ParameterInfoScalar <uint> (-1, -1, "genomeSuffixLengthMax", &genomeSuffixLengthMax));
     parArray.push_back(new ParameterInfoVector <uint> (-1, -1, "genomeFileSizes", &genomeFileSizes));
+    parArray.push_back(new ParameterInfoScalar <string> (-1, -1, "genomeConsensusFile", &genomeConsensusFile));
 
     //read
+    parArray.push_back(new ParameterInfoVector <string> (-1, -1, "readFilesType", &readFilesType));
     parArray.push_back(new ParameterInfoVector <string> (-1, -1, "readFilesIn", &readFilesIn));
+    parArray.push_back(new ParameterInfoScalar <string> (-1, -1, "readFilesPrefix", &readFilesPrefix));
     parArray.push_back(new ParameterInfoVector <string> (-1, -1, "readFilesCommand", &readFilesCommand));
+    
     parArray.push_back(new ParameterInfoScalar <string> (-1, -1, "readMatesLengthsIn", &readMatesLengthsIn));
     parArray.push_back(new ParameterInfoScalar <uint> (-1, -1, "readMapNumber", &readMapNumber));
     parArray.push_back(new ParameterInfoVector <string> (-1, -1, "readNameSeparator", &readNameSeparator));
@@ -133,6 +137,7 @@ Parameters::Parameters() {//initalize parameters info
     parArray.push_back(new ParameterInfoScalar <double>   (-1, -1, "outFilterMismatchNoverLmax", &outFilterMismatchNoverLmax));
     parArray.push_back(new ParameterInfoScalar <double>   (-1, -1, "outFilterMismatchNoverReadLmax", &outFilterMismatchNoverReadLmax));
     parArray.push_back(new ParameterInfoScalar <string>   (-1, -1, "outFilterIntronMotifs", &outFilterIntronMotifs));
+    parArray.push_back(new ParameterInfoScalar <string>   (-1, -1, "outFilterIntronStrands", &outFilterIntronStrands));
 
     //clipping
     parArray.push_back(new ParameterInfoVector <uint>   (-1, -1, "clip5pNbases", &clip5pNbases));
@@ -171,6 +176,7 @@ Parameters::Parameters() {//initalize parameters info
     parArray.push_back(new ParameterInfoScalar <uint>       (-1, -1, "seedPerWindowNmax", &seedPerWindowNmax));
     parArray.push_back(new ParameterInfoScalar <uint>       (-1, -1, "seedNoneLociPerWindow", &seedNoneLociPerWindow));
     parArray.push_back(new ParameterInfoScalar <uint>       (-1, -1, "seedMultimapNmax", &seedMultimapNmax));
+    parArray.push_back(new ParameterInfoScalar <uint>       (-1, -1, "seedSplitMin", &seedSplitMin));
 
     parArray.push_back(new ParameterInfoScalar <uint>       (-1, -1, "alignIntronMin", &alignIntronMin));
     parArray.push_back(new ParameterInfoScalar <uint>       (-1, -1, "alignIntronMax", &alignIntronMax));
@@ -404,7 +410,7 @@ void Parameters::inputParameters (int argInN, char* argIn[]) {//input parameters
     //splitting
     Qsplit=0;
     maxNsplit=10;
-    minLsplit=12;
+    minLsplit=seedSplitMin;
     minLmap=5;
 
 
@@ -728,8 +734,32 @@ void Parameters::inputParameters (int argInN, char* argIn[]) {//input parameters
         exitWithError(errOut.str(), std::cerr, inOut->logMain, EXIT_CODE_PARAMETER, *this);
     };
 
-
-    readNmates=readFilesIn.size(); //for now the number of mates is defined by the number of input files
+    //read parameters
+    if (readFilesType.at(0)=="Fastx") {
+        readFilesTypeN=1;
+    } else if (readFilesType.at(0)=="SAM"){
+        readFilesTypeN=10;
+    } else {
+        ostringstream errOut;
+        errOut <<"EXITING because of FATAL INPUT ERROR: unknown/unimplemented value for --readFilesType: "<<readFilesType.at(0) <<"\n";
+        errOut <<"SOLUTION: specify one of the allowed values: Fastx or SAM\n";
+        exitWithError(errOut.str(), std::cerr, inOut->logMain, EXIT_CODE_PARAMETER, *this);
+    };
+        
+    if (readFilesTypeN==1) {
+        readNmates=readFilesIn.size(); //for now the number of mates is defined by the number of input files
+    } else if (readFilesTypeN==10) {//find the number of mates from the SAM file
+        if (readFilesType.size()==2 && readFilesType.at(1)=="SE") {
+            readNmates=1;
+        } else if (readFilesType.size()==2 && readFilesType.at(1)=="PE") {
+            readNmates=2;
+        } else {
+            ostringstream errOut;
+            errOut <<"EXITING because of FATAL INPUT ERROR: --readFilesType SAM requires specifying SE or PE reads"<<"\n";
+            errOut <<"SOLUTION: specify --readFilesType SAM SE for single-end reads or --readFilesType SAM PE for paired-end reads\n";
+            exitWithError(errOut.str(), std::cerr, inOut->logMain, EXIT_CODE_PARAMETER, *this);
+        };
+    };
 
     if (runMode=="alignReads" && genomeLoad!="Remove" && genomeLoad!="LoadAndExit") {//open reads files to check if they are present
         openReadsFiles();
@@ -823,6 +853,7 @@ void Parameters::inputParameters (int argInN, char* argIn[]) {//input parameters
     outSAMattrPresent.jM=false;
     outSAMattrPresent.jI=false;
     outSAMattrPresent.RG=false;
+    outSAMattrPresent.MC=false;    
     outSAMattrPresent.XS=false;
     outSAMattrPresent.ch=false;
 
@@ -836,7 +867,7 @@ void Parameters::inputParameters (int argInN, char* argIn[]) {//input parameters
     vector<string> vAttr1;
     if (outSAMattributes.at(0)=="None") {
     } else if (outSAMattributes.at(0)=="All"){
-        vAttr1={"NH","HI","AS","nM","NM","MD","jM","jI","ch"};
+        vAttr1={"NH","HI","AS","nM","NM","MD","jM","jI","MC","ch"};
     } else if (outSAMattributes.at(0)=="Standard"){
         vAttr1={"NH","HI","AS","nM"};
     } else {
@@ -875,7 +906,11 @@ void Parameters::inputParameters (int argInN, char* argIn[]) {//input parameters
         } else if (vAttr1.at(ii)== "ch") {
             outSAMattrOrder.push_back(ATTR_ch);
             outSAMattrOrderQuant.push_back(ATTR_ch);
-            outSAMattrPresent.ch=true;            
+            outSAMattrPresent.ch=true;      
+        } else if (vAttr1.at(ii)== "MC") {
+            outSAMattrOrder.push_back(ATTR_MC);
+            outSAMattrOrderQuant.push_back(ATTR_MC);
+            outSAMattrPresent.MC=true;                        
         } else if (vAttr1.at(ii)== "XS") {
             outSAMattrOrder.push_back(ATTR_XS);
             outSAMattrPresent.XS=true;
@@ -894,6 +929,7 @@ void Parameters::inputParameters (int argInN, char* argIn[]) {//input parameters
     if (outSAMattrRG.size()>0 && !outSAMattrPresent.RG) {
         outSAMattrOrder.push_back(ATTR_RG);
         outSAMattrOrderQuant.push_back(ATTR_RG);
+        outSAMattrPresent.RG=true;
         inOut->logMain << "WARNING --outSAMattrRG defines a read group, therefore STAR will output RG attribute" <<endl;
     } else if (outSAMattrRG.size()==0 && outSAMattrPresent.RG) {
             ostringstream errOut;
