@@ -46,6 +46,7 @@ class Parameters {
         uint genomeInsertChrIndFirst; //index of the first inserted chromosome
         uint genomeSuffixLengthMax; //maximum length of the suffixes, has to be longer than read length
         vector <uint> genomeFileSizes; //size of the genome files
+        string genomeConsensusFile;
         
         //binning,windows,anchors
         uint genomeChrBinNbits, genomeChrBinNbases, chrBinN, *chrBin;
@@ -59,16 +60,20 @@ class Parameters {
 
         char genomeNumToNT[6];
         //read parameters
+        vector <string> readFilesType;
+        int readFilesTypeN;
+        string readFilesPrefix;
+        vector <string> readFilesIn, readFilesInTmp;
+        uint32 readFilesN;
+        vector <vector <string> > readFilesNames;
+        vector <string> readFilesCommand;
+        int readFilesIndex;
+        pid_t readFilesCommandPID[MAX_N_MATES];
+
         uint readMapNumber;
         uint iReadAll;
-        int readFilesIndex;
-        uint32 readFilesN;
-        vector <string> readFilesIn, readFilesInTmp;
-        vector <vector <string> > readFilesNames;
         uint readNmates;
         string readMatesLengthsIn;
-        vector <string> readFilesCommand;
-        pid_t readFilesCommandPID[MAX_N_MATES];
 
         vector <string> readNameSeparator;
         vector <char> readNameSeparatorChar;
@@ -114,6 +119,7 @@ class Parameters {
         uint seedNoneLociPerWindow; //max number of aligns from one piece per window
         uint seedSearchStartLmax;
         double seedSearchStartLmaxOverLread; //length of split start points
+        uint seedSplitMin;
 
         //chunk parameters
         uint chunkInSizeBytes,chunkInSizeBytesArray,chunkOutBAMsizeBytes;
@@ -124,14 +130,14 @@ class Parameters {
 
         //SAM output
         string outBAMfileCoordName, outBAMfileUnsortedName, outQuantBAMfileName;
-        string samHeader, samHeaderHD, samHeaderSortedCoord;
+        string samHeader, samHeaderHD, samHeaderSortedCoord, samHeaderExtra;
         string outSAMmode, outSAMstrandField,  outSAMorder, outSAMprimaryFlag;
         vector<string> outSAMattributes, outSAMheaderHD, outSAMheaderPG;
         vector<string> outSAMattrRGline,outSAMattrRGlineSplit,outSAMattrRG;
         uint outSAMmultNmax,outSAMattrIHstart;
         string outSAMheaderCommentFile;
         int outSAMmapqUnique;
-        struct {bool NH,HI,AS,NM,MD,nM,jM,jI,RG,XS,ch;} outSAMattrPresent, outSAMattrPresentQuant;
+        struct {bool NH,HI,AS,NM,MD,nM,jM,jI,RG,XS,ch,MC;} outSAMattrPresent, outSAMattrPresentQuant;
         vector <int> outSAMattrOrder, outSAMattrOrderQuant;
         int outBAMcompression;
         vector <string> outSAMtype;
@@ -186,7 +192,7 @@ class Parameters {
         uint outFilterMatchNmin,outFilterMultimapNmax;//min number of matches
         double outFilterScoreMinOverLread, outFilterMatchNminOverLread;//normalzied to read length
         intScore outFilterScoreMin,outFilterMultimapScoreRange;//min score to output
-        string outFilterIntronMotifs;
+        string outFilterIntronMotifs,outFilterIntronStrands;
         string outFilterType; //type of filtering
         int outFilterBySJoutStage; //indicates the stage of filtering by SJout
 
@@ -351,6 +357,7 @@ class Parameters {
     void inputParameters (int argInN, char* argIn[]); //input parameters: default, from files, from command line
     void openReadsFiles();
     void closeReadsFiles();
+    void readSAMheader(const string readFilesCommandString, const vector<string> readFilesNames);
 
 };
 #endif  // Parameters.h
