@@ -55,6 +55,12 @@ int bamAttrArrayWrite(int32 attr, const char* tagName, char* attrArray ) {
     *( (int32*) (attrArray+3))=attr;
     return 3+sizeof(int32);
 };
+int bamAttrArrayWrite(float attr, const char* tagName, char* attrArray ) {
+    attrArray[0]=tagName[0];attrArray[1]=tagName[1];
+    attrArray[2]='f';
+    *( (float*) (attrArray+3))=attr;
+    return 3+sizeof(int32);
+};
 int bamAttrArrayWrite(char attr, const char* tagName, char* attrArray ) {
     attrArray[0]=tagName[0];attrArray[1]=tagName[1];
     attrArray[2]='A';
@@ -84,6 +90,49 @@ int bamAttrArrayWrite(vector<int32> &attr, const char* tagName, char* attrArray
     return 4+sizeof(int32)+sizeof(int32)*attr.size();
 };
 
+int bamAttrArrayWriteSAMtags(string &attrStr, char *attrArray) {//write bam record into attrArray for string attribute attString
+    size_t pos1=0, pos2=0;
+    int nattr=0;
+    do {//cycle over multiple tags separated by tab
+        pos2 = attrStr.find('\t',pos1);
+        string attr1 = attrStr.substr(pos1, pos2-pos1);
+        pos1=pos2+1;
+        
+        if (attr1.empty())
+            continue; //extra tab at the beginning, or consecutive tabs
+        
+        switch (attr1.at(3)) {
+            case 'i':
+            {
+                int32 a1=stol(attr1.substr(5));
+                nattr += bamAttrArrayWrite(a1,attr1.c_str(),attrArray+nattr);
+                break;
+            };
+            case 'A':
+            {
+                char a1=attr1.at(5);
+                nattr += bamAttrArrayWrite(a1,attr1.c_str(),attrArray+nattr);                
+                break;
+            };                
+                break;
+            case 'Z':
+            {
+                string a1=attr1.substr(5);
+                nattr += bamAttrArrayWrite(a1,attr1.c_str(),attrArray+nattr);                
+                break;
+            };
+            case 'f':
+            {
+                float a1=stof(attr1.substr(5));
+                nattr += bamAttrArrayWrite(a1,attr1.c_str(),attrArray+nattr);                
+                break;
+            };       
+        };
+    } while (pos2!= string::npos);
+    
+    return nattr;
+};
+
 template <typename intType>
 int bamAttrArrayWriteInt(intType xIn, const char* tagName, char* attrArray, Parameters *P) {//adapted from samtools
     attrArray[0]=tagName[0];attrArray[1]=tagName[1];
@@ -144,7 +193,7 @@ int ReadAlign::alignBAM(Transcript const &trOut, uint nTrOut, uint iTrOut, uint
     uint iExMate=0; //last exon of the first mate
 
     uint16 samFLAG=0;
-    uint leftMate=0; //the mate (0 or 1) which is on the left
+    
 
     bool flagPaired = P->readNmates==2;
 
@@ -160,6 +209,15 @@ int ReadAlign::alignBAM(Transcript const &trOut, uint nTrOut, uint iTrOut, uint
         nMates=0;
     };
 
+    uint leftMate=0; //the mate (0 or 1) which is on the left
+    if (flagPaired) {
+        leftMate=trOut.Str;
+    };
+                
+    if (P->outSAMattrPresent.MC) {
+        calcCIGAR(trOut, nMates, iExMate, leftMate);
+    };
+
     for (uint imate=0;imate < (alignType<0 ? nMates:P->readNmates);imate++) {
 
         uint iEx1=0;
@@ -177,28 +235,28 @@ int ReadAlign::alignBAM(Transcript const &trOut, uint nTrOut, uint iTrOut, uint
             if (mateMapped!=NULL && mateMapped[imate]) continue; //this mate was mapped, do not record it as unmapped
             samFLAG=0x4;
             if (P->readNmates==2) {//paired read
-                samFLAG+=0x1 + (imate==0 ? 0x40 : 0x80);
+                samFLAG|=0x1 + (imate==0 ? 0x40 : 0x80);
                 if (mateMapped[1-imate]) {//mate mapped
                     if (trOut.Str!=(1-imate))
                     {//mate strand reverted
-                       samFLAG+=0x20;
+                       samFLAG|=0x20;
                     };
                     mateChr=trOut.Chr;
                     trChrStart=P->chrStart[mateChr];
                     mateStart=trOut.exons[0][EX_G] - trChrStart;
                     mateStrand= trOut.Str == (1-imate) ? 0 : 1;
 
-                    if (!trOut.primaryFlag)
-                    {//mapped mate is not primary
-                        samFLAG+=0x100;
+                    if (!trOut.primaryFlag && P->outSAMunmapped.keepPairs)
+                    {//mapped mate is not primary, keep unmapped mate for each pair, hence need to mark some as not primary
+                        samFLAG|=0x100;
                     };
 
                 } else {//mate unmapped
-                    samFLAG+=0x8;
+                    samFLAG|=0x8;
                 };
             };
 
-            if (readFilter=='Y') samFLAG+=0x200; //not passing quality control
+            if (readFilter=='Y') samFLAG|=0x200; //not passing quality control
 
             if (mateMapped[1-imate])
             {//mate is mapped, fill the infromation from trOut
@@ -215,25 +273,24 @@ int ReadAlign::alignBAM(Transcript const &trOut, uint nTrOut, uint iTrOut, uint
             attrN+=bamAttrArrayWriteInt(trOut.nMM,"nM",attrOutArray+attrN,P);
             attrN+=bamAttrArrayWrite((to_string((uint) alignType)).at(0), "uT",attrOutArray+attrN); //cast to uint is only necessary for old compilers
             if (!P->outSAMattrRG.empty()) attrN+=bamAttrArrayWrite(P->outSAMattrRG.at(readFilesIndex),"RG",attrOutArray+attrN);
-
         } else {//this mate is mapped
             if (flagPaired) {//paired reads
                 samFLAG=0x0001;
                 if (iExMate==trOut.nExons-1) {//single mate
-                    if (mateChr>P->nChrReal) samFLAG+=0x0008; //not mapped as pair
+                    if (mateChr>P->nChrReal) samFLAG|=0x0008; //not mapped as pair
                 } else {//properly paired
-                    samFLAG+=0x0002; //mapped as pair
+                    samFLAG|=0x0002; //mapped as pair
                 };
             } else {//single end
                 samFLAG=0;
             };
 
-            if (readFilter=='Y') samFLAG+=0x200; //not passing quality control
+            if (readFilter=='Y') samFLAG|=0x200; //not passing quality control
 
             if (alignType==-11 || alignType==-12 || alignType==-13) {
-                samFLAG+=0x800; //mark chimeric alignments
+                samFLAG|=0x800; //mark chimeric alignments
             } else {//only non-chimeric alignments will be marked as non-primary, since chimeric are already marked with 0x800
-                if (!trOut.primaryFlag) samFLAG +=0x100;//mark not primary align
+                if (!trOut.primaryFlag) samFLAG|=0x100;//mark not primary align
             };
 
             iEx1 = (imate==0 ? 0 : iExMate+1);
@@ -242,17 +299,16 @@ int ReadAlign::alignBAM(Transcript const &trOut, uint nTrOut, uint iTrOut, uint
             Str= trOut.Str;//note that Strand = the mate on the left
 
             if (Mate==0) {
-                samFLAG += Str*0x10;
-                if (nMates==2) samFLAG += (1-Str)*0x20;
+                samFLAG|= Str*0x10;
+                if (nMates==2) samFLAG|= (1-Str)*0x20;
             } else {//second mate strand need to be reverted
-                samFLAG += (1-Str)*0x10;
-                if (nMates==2) samFLAG += Str*0x20;
+                samFLAG|= (1-Str)*0x10;
+                if (nMates==2) samFLAG|= Str*0x20;
             };
 
             if (flagPaired) {
-                leftMate=Str;
-                samFLAG += (Mate==0 ? 0x0040 : 0x0080);
-                if (flagPaired && nMates==1 && mateStrand==1) samFLAG +=0x20;//revert strand using inout value of mateStrand (e.g. for chimeric aligns)
+                samFLAG|= (Mate==0 ? 0x0040 : 0x0080);
+                if (flagPaired && nMates==1 && mateStrand==1) samFLAG|=0x20;//revert strand using inout value of mateStrand (e.g. for chimeric aligns)
             };
 
 
@@ -369,6 +425,12 @@ int ReadAlign::alignBAM(Transcript const &trOut, uint nTrOut, uint iTrOut, uint
                             attrN+=bamAttrArrayWrite('1',"ch",attrOutArray+attrN);
                         };                        
                         break;
+                    case ATTR_MC:
+                        if (nMates>1) 
+                        {//chimeric alignment
+                            attrN+=bamAttrArrayWrite(matesCIGAR[1-imate],"MC",attrOutArray+attrN);
+                        };                        
+                        break;                        
                     default:
                         ostringstream errOut;
                         errOut <<"EXITING because of FATAL BUG: unknown/unimplemented SAM atrribute (tag): "<<outSAMattrOrder[ii] <<"\n";
@@ -377,6 +439,12 @@ int ReadAlign::alignBAM(Transcript const &trOut, uint nTrOut, uint iTrOut, uint
                 };
             };
         };
+            
+        if (P->readFilesTypeN==10) {
+//             if (readNameExtra[Mate].size()<1)
+//                 cout << iReadAll <<" " <<readName <<endl; 
+            attrN+=bamAttrArrayWriteSAMtags(readNameExtra[Mate],attrOutArray+attrN);
+        };        
 ////////////////////////////// prepare sequence and qualities
         char seqMate[DEF_readSeqLengthMax+1], qualMate[DEF_readSeqLengthMax+1];
         char *seqOut=NULL, *qualOut=NULL;
