@@ -202,7 +202,9 @@ bool ReadAlign::chimericDetection() {
 
                     uint jR, jRbest=0;
                     int jScore=0,jMotif=0,jScoreBest=-999999,jScoreJ=0;
-                    for (jR=0; jR<roStart1+trChim[1].exons[e1][EX_L]-roStart0-1; jR++) {//scan through the exons to find a canonical junction, and check for mismatches
+                    uint jRmax = roStart1+trChim[1].exons[e1][EX_L];
+                    jRmax = jRmax>roStart0 ? jRmax-roStart0-1 : 0;
+                    for (jR=0; jR<jRmax; jR++) {//scan through the exons to find a canonical junction, and check for mismatches
 
                         if (jR==readLength[0]) jR++; //skip the inter-mate base
 
@@ -477,7 +479,10 @@ bool ReadAlign::chimericDetection() {
                         <<"\t"<< P->chrName[trChim[1].Chr] <<"\t"<< chimJ1 - P->chrStart[trChim[1].Chr]+1 <<"\t"<< (trChim[1].Str==0 ? "+":"-") \
                         <<"\t"<< chimMotif <<"\t"<< chimRepeat0  <<"\t"<< chimRepeat1 <<"\t"<< readName+1 \
                         <<"\t"<< trChim[0].exons[0][EX_G] - P->chrStart[trChim[0].Chr]+1 <<"\t"<< outputTranscriptCIGARp(trChim[0]) \
-                        <<"\t"<< trChim[1].exons[0][EX_G] - P->chrStart[trChim[1].Chr]+1 <<"\t"<<  outputTranscriptCIGARp(trChim[1]) <<"\n"; //<<"\t"<< trChim[0].exons[0][EX_iFrag]+1 --- no need for that, since trChim[0] is always on the first mate
+                        <<"\t"<< trChim[1].exons[0][EX_G] - P->chrStart[trChim[1].Chr]+1 <<"\t"<<  outputTranscriptCIGARp(trChim[1]);//<<"\t"<< trChim[0].exons[0][EX_iFrag]+1 --- no need for that, since trChim[0] is always on the first mate
+                if (P->outSAMattrPresent.RG)
+                    chunkOutChimJunction <<"\t"<< P->outSAMattrRG.at(readFilesIndex);
+                chunkOutChimJunction << "\n"; 
             };
         };//chimeric score
     };//chimeric search
