@@ -17,24 +17,24 @@ uint ReadAlign::outputTranscriptSAM(Transcript const &trOut, uint nTrOut, uint i
                 uint16 samFLAG=0x4;
                 if (P->readNmates==2)
                 {//paired read
-                    samFLAG+=0x1 + (imate==0 ? 0x40 : 0x80);
+                    samFLAG|=0x1 + (imate==0 ? 0x40 : 0x80);
                     if (mateMapped[1-imate])
                     {//mate mapped
                         if ( trOut.Str != (1-imate) )
                         {
-                            samFLAG+=0x20;//mate strand reverted
+                            samFLAG|=0x20;//mate strand reverted
                         };
                     } else
                     {//mate unmapped
-                        samFLAG+=0x8;
+                        samFLAG|=0x8;
                     };
                 };
 
-                if (readFilter=='Y') samFLAG+=0x200; //not passing quality control
+                if (readFilter=='Y') samFLAG|=0x200; //not passing quality control
 
-                if (mateMapped[1-imate] && !trOut.primaryFlag)
-                {//mapped mate is not primary
-                    samFLAG+=0x100;
+                if (mateMapped[1-imate] && !trOut.primaryFlag && P->outSAMunmapped.keepPairs)
+                {//mapped mate is not primary, keep unmapped mate for each pair, hence need to mark some as not primary
+                    samFLAG|=0x100;
                 };
 
                 *outStream << readName+1 <<"\t"<< samFLAG \
@@ -49,6 +49,10 @@ uint ReadAlign::outputTranscriptSAM(Transcript const &trOut, uint nTrOut, uint i
                 *outStream <<"\t"<< '0' <<"\t"<< Read0[imate] <<"\t"<< (readFileType==2 ? Qual0[imate]:"*") \
                         <<"\tNH:i:0" <<"\tHI:i:0" <<"\tAS:i:"<<trOut.maxScore <<"\tnM:i:"<<trOut.nMM<<"\tuT:A:" <<unmapType;
                 if (!P->outSAMattrRG.empty()) *outStream<< "\tRG:Z:" <<P->outSAMattrRG.at(readFilesIndex);
+                
+                if (P->readFilesTypeN==10 && !readNameExtra[imate].empty()) {//SAM files as input - output extra attributes
+                    *outStream << "\t" <<readNameExtra[imate];
+                };
                 *outStream <<"\n";
 
             };
@@ -93,32 +97,40 @@ uint ReadAlign::outputTranscriptSAM(Transcript const &trOut, uint nTrOut, uint i
 
     if (readFilter=='Y') samFlagCommon+=0x200; //not passing quality control    
 
-    uint samFLAG;
+    uint Str= trOut.Str;//note that Strand = the mate on the left
     uint leftMate=0; //the mate (0 or 1) which is on the left
+    if (flagPaired) {
+        leftMate=Str;
+    };
+    
+    if (P->outSAMattrPresent.MC) {
+        calcCIGAR(trOut, nMates, iExMate, leftMate);
+    };
+    
+    uint samFLAG;
+    
     for (uint imate=0;imate<nMates;imate++) {
         samFLAG=samFlagCommon;
 
         uint iEx1 = (imate==0 ? 0 : iExMate+1);
         uint iEx2 = (imate==0 ? iExMate : trOut.nExons-1);
         uint Mate=trOut.exons[iEx1][EX_iFrag];
-        uint Str= trOut.Str;//note that Strand = the mate on the left
-
+ 
         if (Mate==0) {
-            samFLAG += Str*0x10;
-            if (nMates==2) samFLAG += (1-Str)*0x20;
+            samFLAG|= Str*0x10;
+            if (nMates==2) samFLAG|= (1-Str)*0x20;
         } else {//second mate strand need to be reverted
-            samFLAG += (1-Str)*0x10;
-            if (nMates==2) samFLAG += Str*0x20;
+            samFLAG|= (1-Str)*0x10;
+            if (nMates==2) samFLAG|= Str*0x20;
         };
 
         if (flagPaired) {
-            leftMate=Str;
-            samFLAG += (Mate==0 ? 0x0040 : 0x0080);
-            if (flagPaired && nMates==1 && mateStrand==1) samFLAG +=0x20;//revert strand using inout value of mateStrand (e.g. for chimeric aligns)
+            samFLAG|= (Mate==0 ? 0x0040 : 0x0080);
+            if (flagPaired && nMates==1 && mateStrand==1) samFLAG|=0x20;//revert strand using inout value of mateStrand (e.g. for chimeric aligns)
         };
 
         //not primary align?
-        if (!trOut.primaryFlag) samFLAG +=0x100;
+        if (!trOut.primaryFlag) samFLAG|=0x100;
 
         //empty streams
         samStreamCIGAR.str(std::string());
@@ -269,6 +281,7 @@ uint ReadAlign::outputTranscriptSAM(Transcript const &trOut, uint nTrOut, uint i
             };
             tagMD+=to_string(matchN);
         };
+        
         for (uint ii=0;ii<P->outSAMattrOrder.size();ii++) {
             switch (P->outSAMattrOrder[ii]) {
                 case ATTR_NH:
@@ -305,6 +318,11 @@ uint ReadAlign::outputTranscriptSAM(Transcript const &trOut, uint nTrOut, uint i
                 case ATTR_RG:
                     *outStream<< "\tRG:Z:" <<P->outSAMattrRG.at(readFilesIndex);
                     break;
+                case ATTR_MC:
+                    if (nMates>1) {
+                        *outStream<< "\tMC:Z:" <<matesCIGAR[1-imate];
+                    };
+                    break;                    
                 case ATTR_ch:
                     //do nothing - this attribute only worlks for BAM output
                     break;
@@ -316,9 +334,10 @@ uint ReadAlign::outputTranscriptSAM(Transcript const &trOut, uint nTrOut, uint i
             };
         };
 
-
-//         for (uint ii=0;ii<customAttr.size();ii++) *outStream <<"\t"<< customAttr.at(ii); //output all attributes in the right order
-
+        if (P->readFilesTypeN==10 && !readNameExtra[imate].empty()) {//SAM files as input - output extra attributes
+             *outStream << "\t" << readNameExtra.at(imate);
+        };
+        
         *outStream << "\n"; //done with one SAM line
     };//for (uint imate=0;imate<nMates;imate++)
 
